<?php
/**
 * Plugin Name: Serveproxy Image CDN Free
 * Description: Serveproxy offers a free CDN with automatic AVIF image conversion and compression, enhancing your WordPress site's performance. Deliver content faster and improve user experience effortlessly.
 * Version: 1.1
 * Author: Serveproxy
 * License: GPLv2 or later
 */
 
 if (!defined('ABSPATH')) exit; // Exit if accessed directly
 
 class ImageProxyPrefixer {
     const MAIN_FILE = __FILE__;
     static $content_url;
     
     private static $proxy_prefix = "https://serveproxy.com/?url=";
     private static $image_extensions = array('jpg', 'jpeg', 'png', 'gif', 'bmp', 'webp', 'tiff', 'svg');
 
     public function __construct() {
         $this->content_url = str_replace(['http://', 'https://'], '', content_url());
         
         if (!$this->is_local_site()) { 
             add_action('template_redirect', array($this, 'start_buffering'));
         }
     }
 
     public function start_buffering() {
         ob_start(array($this, 'add_proxy_prefix'));
     }
 
     public function add_proxy_prefix($content) {
         $pattern = '/(' . preg_quote(content_url(), '/') . '\/[^\s"\']+\.(' . implode('|', self::$image_extensions) . '))/i';
         $replacement = self::$proxy_prefix . '$1';
         return preg_replace($pattern, $replacement, $content);
     }
 
     public function is_local_site() {
         $site_url = site_url();
         $is_local = $site_url && false === strpos($site_url, '.');
 
         if ('local' === wp_get_environment_type()) {
             $is_local = true;
         }
 
         $known_local = array(
             '#\.local$#i',
             '#\.localhost$#i',
             '#\.test$#i',
             '#\.docksal$#i',
             '#\.docksal\.site$#i',
             '#\.dev\.cc$#i',
             '#\.lndo\.site$#i',
             '#^https?://127\.0\.0\.1$#',
         );
 
         if (!$is_local) {
             foreach ($known_local as $url) {
                 if (preg_match($url, $site_url)) {
                     $is_local = true;
                     break;
                 }
             }
         }
 
         return $is_local;
     }
 }
 
 new ImageProxyPrefixer();
 